@@ -37,6 +37,8 @@ struct config {
     const char* font_face;   ///< Font name
     size_t font_size;        ///< Font size
     argb_t font_color;       ///< Font color
+    bool slideshow;          ///< Slide show mode
+    size_t slideshow_sec;    ///< Slide show mode timing
     enum config_order order; ///< File list order
     bool recursive;          ///< Read directories recursively
     bool all_files;          ///< Open all files from the same directory
@@ -55,13 +57,6 @@ struct config* config_init(void);
  */
 void config_free(struct config* ctx);
 
-/**
- * Check if configuration is incompatible.
- * @param ctx configuration context
- * @return configuration status, true if configuration is ok
- */
-bool config_check(const struct config* ctx);
-
 // Configuration setters
 bool config_set_scale(struct config* ctx, const char* val);
 bool config_set_background(struct config* ctx, const char* val);
@@ -70,4 +65,5 @@ bool config_set_geometry(struct config* ctx, const char* val);
 bool config_set_font_name(struct config* ctx, const char* val);
 bool config_set_font_size(struct config* ctx, const char* val);
 bool config_set_order(struct config* ctx, const char* val);
+bool config_set_slideshow_sec(struct config* ctx, const char* val);
 bool config_set_appid(struct config* ctx, const char* val);
