@@ -5,7 +5,6 @@
 #include "buildcfg.h"
 #include "config.h"
 #include "formats/loader.h"
-#include "image.h"
 #include "sway.h"
 #include "viewer.h"
 
@@ -28,6 +27,7 @@ static const struct cmdarg arguments[] = {
     { 'r', "recursive",  NULL,      "read directories recursively" },
     { 'a', "all",        NULL,      "open all files from the same directory" },
     { 'm', "mark",       NULL,      "enable marking mode" },
+    { 'l', "slideshow",  NULL,      "activate slideshow mode on startup" },
     { 'f', "fullscreen", NULL,      "show image in full screen mode" },
     { 's', "scale",      "SCALE",   "set initial image scale: [optimal]/fit/real" },
     { 'b', "background", "XXXXXX",  "set image background color: none/[grid]/RGB" },
@@ -113,6 +113,9 @@ static int parse_cmdargs(int argc, char* argv[], struct config* cfg)
             case 'm':
                 cfg->mark_mode = true;
                 break;
+            case 'l':
+                cfg->slideshow = true;
+                break;
             case 'f':
                 cfg->fullscreen = true;
                 break;
@@ -150,7 +153,7 @@ static int parse_cmdargs(int argc, char* argv[], struct config* cfg)
             case 'v':
                 puts(APP_NAME " version " APP_VERSION ".");
                 puts("https://github.com/artemsen/swayimg");
-                printf("Supported formats: %s.\n", supported_formats());
+                printf("Supported formats: %s.\n", supported_formats);
                 return 0;
             case 'h':
                 print_help();
@@ -189,56 +192,80 @@ static void sway_setup(struct config* cfg)
  */
 int main(int argc, char* argv[])
 {
-    int rc;
+    bool rc = false;
     struct config* cfg = NULL;
-    struct file_list* files = NULL;
-    int num_files;
+    struct image_list* list = NULL;
+    struct viewer* viewer = NULL;
+    struct ui* ui = NULL;
+    struct ui_handlers handlers;
     int index;
 
     cfg = config_init();
     if (!cfg) {
-        rc = EXIT_FAILURE;
         goto done;
     }
 
     // parse command arguments
     index = parse_cmdargs(argc, argv, cfg);
     if (index == 0) {
-        rc = EXIT_SUCCESS;
+        rc = true;
         goto done;
     }
     if (index < 0) {
-        rc = EXIT_FAILURE;
         goto done;
     }
-    config_check(cfg);
+
+    // check configuration
+    if (cfg->geometry.width) {
+        if (!cfg->sway_wm) {
+            fprintf(stderr,
+                    "Warning: unable to set window geometry without sway\n");
+        }
+        if (cfg->fullscreen) {
+            fprintf(stderr,
+                    "Warning: window geometry used in fullscreen mode\n");
+        }
+    }
 
     // compose file list
-    num_files = argc - index;
-    if (num_files == 1 && strcmp(argv[index], "-") == 0) {
-        // reading from pipe, skip file list composing
-    } else {
-        files = flist_init((const char**)&argv[index], num_files, cfg);
-        if (!files) {
-            fprintf(stderr, "Unable to compose file list from input args\n");
-            rc = EXIT_FAILURE;
-            goto done;
-        }
+    list = image_list_init((const char**)&argv[index], argc - index, cfg);
+    if (!list) {
+        goto done;
     }
 
     if (cfg->sway_wm && !cfg->fullscreen) {
         sway_setup(cfg);
     }
 
-    rc = run_viewer(cfg, files) ? EXIT_SUCCESS : EXIT_FAILURE;
+    // create ui
+    handlers.on_redraw = viewer_on_redraw;
+    handlers.on_resize = viewer_on_resize;
+    handlers.on_keyboard = viewer_on_keyboard;
+    handlers.on_timer = viewer_on_timer;
+    ui = ui_create(cfg, &handlers);
+    if (!ui) {
+        goto done;
+    }
 
-    if (cfg->mark_mode && files && rc == EXIT_SUCCESS) {
-        flist_mark_print(files);
+    // create viewer
+    viewer = viewer_create(cfg, list, ui);
+    if (!viewer) {
+        goto done;
+    }
+    handlers.data = viewer;
+
+    // run main loop
+    rc = ui_run(ui);
+
+    if (rc && cfg->mark_mode) {
+        image_list_mark_print(list);
     }
 
 done:
-    flist_free(files);
+    viewer_free(viewer);
+    ui_free(ui);
+    image_list_free(list);
     config_free(cfg);
 
-    return rc;
+    return rc ? EXIT_SUCCESS : EXIT_FAILURE;
 }
